summaryrefslogtreecommitdiffstats
path: root/style/qtcurve.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-03 22:54:09 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-03 22:54:09 -0600
commitb063e7d3b4a86f46759db906ff2d907f33c96696 (patch)
tree2a9c1c3237cc2b7d2467c019048b118f66339266 /style/qtcurve.cpp
parentf7ed00bca5c1789e9dfc80baa46ea6b3eb99f377 (diff)
downloadtde-style-qtcurve-b063e7d3b4a86f46759db906ff2d907f33c96696.tar.gz
tde-style-qtcurve-b063e7d3b4a86f46759db906ff2d907f33c96696.zip
Rename KStyle to TDEStyle to avoid conflicts with KDE4
Diffstat (limited to 'style/qtcurve.cpp')
-rw-r--r--style/qtcurve.cpp10
1 files changed, 5 insertions, 5 deletions
diff --git a/style/qtcurve.cpp b/style/qtcurve.cpp
index 4eebbc9..8c2585c 100644
--- a/style/qtcurve.cpp
+++ b/style/qtcurve.cpp
@@ -4477,7 +4477,7 @@ static TQString elliditide(const TQString &text, const TQFontMetrics &fontMetric
return title;
}
-void QtCurveStyle::drawKStylePrimitive(KStylePrimitive kpe, TQPainter *p, const TQStyleControlElementData &ceData, ControlElementFlags elementFlags,
+void QtCurveStyle::drawTDEStylePrimitive(TDEStylePrimitive kpe, TQPainter *p, const TQStyleControlElementData &ceData, ControlElementFlags elementFlags,
const TQRect &r, const TQColorGroup &cg, SFlags flags,
const TQStyleOption &opt, const TQWidget *widget) const
{
@@ -4630,7 +4630,7 @@ void QtCurveStyle::drawKStylePrimitive(KStylePrimitive kpe, TQPainter *p, const
}
break;
default:
- BASE_STYLE::drawKStylePrimitive(kpe, p, ceData, elementFlags, r, cg, flags, opt, widget);
+ BASE_STYLE::drawTDEStylePrimitive(kpe, p, ceData, elementFlags, r, cg, flags, opt, widget);
}
}
@@ -5337,7 +5337,7 @@ void QtCurveStyle::drawControl(ControlElement control, TQPainter *p, const TQSty
if (!cr.isValid())
return;
- if(opts.boldProgress) // This is the only change fro the KStyle code!
+ if(opts.boldProgress) // This is the only change fro the TDEStyle code!
{
TQFont font = p->font();
font.setBold(true);
@@ -6322,7 +6322,7 @@ void QtCurveStyle::drawComplexControl(ComplexControl control, TQPainter *p, cons
}
case CC_Slider:
//
// Note: Can't use KStyle's drawing routine, as this doesnt work for sliders on gradient
// toolbars. It also draws groove, focus, slider - wherease QtCurve needs groove,
// slider, focus. We also ony double-buffer if not on a toolbar, as we dont know
// the background, etc, if on a toolbar - and that is handled in eventFilter
@@ -6885,7 +6885,7 @@ int QtCurveStyle::pixelMetric(PixelMetric metric, const TQStyleControlElementDat
}
}
-int QtCurveStyle::kPixelMetric(KStylePixelMetric kpm, const TQStyleControlElementData &ceData, ControlElementFlags elementFlags, const TQWidget *widget) const
+int QtCurveStyle::kPixelMetric(TDEStylePixelMetric kpm, const TQStyleControlElementData &ceData, ControlElementFlags elementFlags, const TQWidget *widget) const
{
switch(kpm)
{
@@ -6322,7 +6322,7 @@ void QtCurveStyle::drawComplexControl(ComplexControl control, TQPainter *p, cons
case CC_Slider:
//
- // Note: Can't use KStyle's drawing routine, as this doesnt work for sliders on gradient
+ // Note: Can't use TDEStyle's drawing routine, as this doesnt work for sliders on gradient
// toolbars. It also draws groove, focus, slider - wherease QtCurve needs groove,
// slider, focus. We also ony double-buffer if not on a toolbar, as we dont know